pub struct InventorySummary {
    pub asin: Option<String>,
    pub fn_sku: Option<String>,
    pub seller_sku: Option<String>,
    pub condition: Option<String>,
    pub inventory_details: Option<Box<InventoryDetails>>,
    pub last_updated_time: Option<String>,
    pub product_name: Option<String>,
    pub total_quantity: Option<i32>,
}
InventorySummary : Inventory summary for a specific item.

Fields

asin: Option<String>

The Amazon Standard Identification Number (ASIN) of an item.

fn_sku: Option<String>

Amazon’s fulfillment network SKU identifier.

seller_sku: Option<String>

The seller SKU of the item.

condition: Option<String>

The condition of the item as described by the seller (for example, New Item).

inventory_details: Option<Box<InventoryDetails>>last_updated_time: Option<String>

The date and time that any quantity was last updated.

product_name: Option<String>

The localized language product title of the item within the specific marketplace.

total_quantity: Option<i32>

The total number of units in an inbound shipment or in Amazon fulfillment centers.

Implementations

Inventory summary for a specific item.